/*
------------------------------------------------------------------------
Test problem for getDP

Created by Matthias A. Fenner 
(including several patches obtained from the getDP archives; thanks to everybody!)

Last modification August 23, 2004
------------------------------------------------------------------------

Description:

One dimensional heat conduction in a zylindrical quartz tube (rather
thick-walled, 1m inner radius, 5m outer!) with  different temperatures
on the inner and outer face.
(Actually solved in a 2D region) lambda = const.


Provided there is a Zyl-2d.msh mesh file around just type 
"getdp  zyl-2d -pre linear -cal -pos map" 
in a command shell to solve the problem

Th.dat shows the temperature profile in radial direction which can be
compared to the analytical solution as shown in zyl-2d.pdf

Further checks: 
1. Check the conservation of heat flow!
2. There is also an analytical solution for a sphere, check that as well

Open questions:
-
*/

Group {
  inner  = Region[8] ;
  outer = Region[7];
  top = Region[10];
  bottom = Region[11];
  wall = Region[9];


  Vol_The = Region[{wall, inner, outer, top, bottom}] ; // see comment in Thermal.pro
  boundary = Region[{inner, outer, top, bottom}];
}

Constraint {
  { Name Sta_T ; Type Assign;
    Case {
      { Region inner; Value 30.; }
      { Region outer; Value 10.; }
    }
  }
}

Function {
  k[ Vol_The ] =  1.45 ; // [W / mK] quartz around 20C
}

Include "Thermal.pro"

PostOperation {
        
    { Name map ; NameOfPostProcessing map ;
      Operation {
        Print[ T, OnElementsOf Vol_The , File "T.pos"];
        Print[ q, OnElementsOf Vol_The , File "q.pos"];
        Print[ T, OnLine { {1.,0.5,0} {5.,0.5,0} } {50} , Format Table, File "Th.dat"];
      }
    }    
}
