/*
------------------------------------------------------------------------
Test problem for getDP

Created by Matthias A. Fenner 
(including several patches obtained from the getDP archives; thanks to everybody!)

Last modification August 27, 2004
------------------------------------------------------------------------

Description:

Stationary state of one-dimensional Copper wire with ends held at 5
and 150 Kelvin. lambda = lambda(T) 

Provided there is a current-lead.msh mesh file around just type 
"getdp  current-lead -pre nonlinear -cal -pos pos" 
in a command shell to solve the problem

Option "-pos ascii" T.dat shows the temperature profile which can be
compared to the profile obtained in the way described in current-lead.pdf

Further checks: 
-

Open questions: 

How do I set the solution of problem 3 as an initial condition for a
non-staionary problem to investigate the behavior after switching on the
current (I could not get to work the TransferInitSolution type)? 

*/

Group {
  hot = Region[4];
  cold = Region[3];
  lead = Region[2];

  Vol_The = Region[{hot,cold, lead}] ;
  NL_NbrMaxIter = 50;
  NL_Eps = 1.e-4;
  NL_Relax = 1.;
}

Constraint {
  { Name T_Static ; Type Assign;
    Case {
      { Region hot; Value 150.; }
      { Region cold; Value 5.; }
    }
  }
}

#include "Copper-data.dat"; // definition of the lists lambda, rho and Cv

Function {

k[] = InterpolationLinear[$1]{List[lambda]};
//k[] = 438.05227 + 2 * 50001.08348/3.14159265 * 27.78459/ ( 4 * ($1 - 28.52782)^2 + 27.78459^2);

rho_el[] = InterpolationLinear[$1]{List[rho]};

I=.325;			//Ampere
area=3.976e-8;  	// 0.225 Dia wire
j=I/area;
qdot[]=j^2*rho_el[$1] * 1e-8 ; 		//rho is in micro Ohm cm

}

Include "Thermal.pro"

PostOperation {
        
    { Name pos ; NameOfPostProcessing The ;
      Operation {
//        Print[ T, OnElementsOf Vol_The , File "T.pos"];
//        Print[ q_abs, OnLine { {0,0,0} {1.5,0,0} } {10}, File "q.pos"];
        Print[ T, OnLine { {0,0,0} {1.,0,0} } {100}, File "Tcut.pos"];
     }
    }    

    { Name ascii ; NameOfPostProcessing The ;
      Operation {
        Print[ T, OnLine { {0,0,0} {1.,0,0} } {100}, Format Table, File "T.dat"];
      }
    }

}
