/*
------------------------------------------------------------------------
Test problem for getDP

Created by Matthias A. Fenner 
(including several patches obtained from the getDP archives; thanks to everybody!)

Last modification August 25, 2004
------------------------------------------------------------------------

Description:

Non-stationary, one-dimensional temperature profile in an infinite qurtz
plate of thickness d = 0.1m with center in the origin (0,0,0) subject to
a sudden temperature change on it's surfaces (mirror symmetry of the
problem is exploited here, lambda = const != f ( t, r, T ) ).

Provided there is a Plate-dyn.msh mesh file around just type 
"getdp  Plate-dyn -pre linear -cal -pos pos" 
in a command shell to solve the problem
Best viewing is with "cut.pos" as 2D Space Table

Option "-pos ascii" cut.dat shows the temperature profile after 1000 s
which compared to the series approximation as shown in plate-dyn.pdf

Further checks: 
-

Open questions: 

The Init type constraint is sensitive to the order of in which the
regions are initiated !!??
 
*/

Group {
  left = Region[100];
  right = Region[200];
  plate = Region[300];

  Sur_The = Region[left];
  Vol_The = Region[{plate,left/*,right*/}] ;  
		//taking region right out of the integration region 
		//makes it an implicit Neumann boundary !?
		//If included you get a temperature gradient
		//in the center of the plate which is not conform 
		//with the symmetry
}

Function {
k[]=1.45;		// W / m*K
rhoc[]= 2.2e3 * 700;    // kg/m^3 x J / kg*K 

TimeFct[] = ($Time < 10) ? 1 : 10 ;
t0 = 0;
t1 = 1000;
dt = 5 ;
}

Constraint {
/* Case One
  { Name Dyn_T ; Type Init;
    Case {
      { Region Sur_The; Value 100.0 ;}
      { Region plate; Value 10.0 ;}
		// If you swap these two lines you get a stationary 
		// solution with T(x) = 10 forever !!??
    }
  }
*/

// Case Two
/* 
   It took me quite some time to figure out these constraints 
   because I did not notice the possibility of assigning different types
   to the individual regions. Confer Case One which solves a different
   problem.
*/
  { Name Dyn_T ; /*Type Assign;*/
    Case {
      { Region Sur_The; Type Assign; Value 10.0; TimeFunction TimeFct[]; }
      { Region Vol_The; Type Init; Value 10.0 ;}
		// If you swap these two lines you get a stationary 
		// solution with T(x) = 10 forever !!??
    }
  }
}

Include "Thermal.pro"

PostOperation {
    { Name pos ; NameOfPostProcessing The ;
      Operation {
	Print[ T, OnLine { {-.05,0,0} {0,0,0} } {500} , File "cut.pos"];
//        Print[ q_abs, OnLine { {-.05,0,0} {0,0,0} } {500} , File "qcut.pos"];
      }
    }    

    { Name ascii ; NameOfPostProcessing The ;
      Operation {
        Print[ T, OnLine { {-.05,0,0} {0,0,0} } {500} , TimeStep 200 , Format Table, File "cut.dat"];
      }
    }
}
